@@ -10,7 +10,7 @@ def ter():
     time.sleep(1.5)
 
     def inicializar_juego():
-    #"""Función que incializa los valores del juego"""
+        """Función que incializa los valores del juego"""
         juego_en_curso = True
         jugadores = [[input("Jugador 1: "),"X"], [input("Jugador 2: "),"O"]]
         jugador_actual = random.randint(0, 1)
@@ -29,8 +29,8 @@ def ter():
                     return False
         return True
     def comprobar_ganador(jugador, tablero_actual):
-    #"""Comprueba si ha ganado el jugador actual, devuelve True o False"""
-    #Comprobar por filas
+        """Comprueba si ha ganado el jugador actual, devuelve True o False"""
+        #Comprobar por filas
         for i in range(3):
             ganador = True
             for x in range(3):
@@ -48,7 +48,7 @@ def ter():
                     break
             if ganador:
                 return ganador
-    #Comprobar por diagonales
+        #Comprobar por diagonales
         ganador = True
         for i in range(3):
             if tablero_actual[i][i] != jugador[1]:
@@ -74,24 +74,24 @@ def ter():
             print(Fore.RESET + " ")
             break
         cls()
-    #Nuevo turno
+        #Nuevo turno
         print("Turno de: " + jugadores[jugador_actual][0])
         time.sleep(0.5)
-    #Dibujar tablero
+        #Dibujar tablero
         print("0 1 2 3")
         coordenadas_vertical = 1
         for linea in tablero:
             print(coordenadas_vertical, linea[0], linea[1], linea[2])
             coordenadas_vertical += 1
         time.sleep(1)
-    #Selección de casilla
+        #Selección de casilla
         coordenada_fila, coordenada_columna = list(map(int, input("Elige coordenadas: ")))
-    #Actualizar tablero
+        #Actualizar tablero
         tablero = actualizar_tablero(jugadores[jugador_actual], coordenada_fila, coordenada_columna, tablero)
-    #Comprobamos si ha ganado
+        #Comprobamos si ha ganado
         if comprobar_ganador(jugadores[jugador_actual], tablero):
             juego_en_curso = False
-        #Dibujar tablero
+            #Dibujar tablero
             cls()
             print("0 1 2 3")
             coordenadas_vertical = 1
@@ -103,7 +103,6 @@ def ter():
             time.sleep(1)
             print(Fore.YELLOW + "Lo siento", jugadores[jugador_actual][1], "intentaló la próxima vez :D")
             print(Fore.RESET + " ")
-    #Cambio de jugador
+            time.sleep(2)
+        #Cambio de jugador
         jugador_actual = 1 if jugador_actual == 0 else 0
-
-ter()
